import { PropType } from 'vue';
import { MenuOptions, MenuItem, ContextMenuPositionData } from './ContextMenuDefine';
import { GlobalHasSlot, GlobalRenderSlot } from './ContextMenu.vue';
export interface MenuItemContext {
    focus: () => void;
    blur: () => void;
    showSubMenu: () => void;
    getElement: () => HTMLElement | undefined;
    isDisabledOrHidden: () => boolean;
    click: () => void;
}
export interface SubMenuContext {
    isTopLevel: () => boolean;
    closeSelfAndActiveParent: () => void;
    closeCurrentSubMenu: () => void;
    moveCurrentItemFirst: () => void;
    moveCurrentItemLast: () => void;
    moveCurrentItemDown: () => void;
    moveCurrentItemUp: () => void;
    focusCurrentItem: () => void;
    openCurrentItemSubMenu: () => void;
    triggerCurrentItemClick: () => void;
}
export interface SubMenuParentContext {
    container: HTMLElement;
    zIndex: number;
    adjustPadding: number;
    getMyPosition: () => ContextMenuPositionData;
    getParentWidth: () => number;
    getParentAbsY: () => number;
    addOpenedSubMenu: (closeFn: () => void) => void;
    closeOtherSubMenu: () => void;
    closeOtherSubMenuWithTimeOut: () => void;
    checkCloseOtherSubMenuTimeOut: () => boolean;
    addChildMenuItem: (item: MenuItemContext, index?: number) => void;
    removeChildMenuItem: (item: MenuItemContext) => void;
    markActiveMenuItem: (item: MenuItemContext, updateState?: boolean) => void;
    markThisOpenedByKeyBoard: () => void;
    isOpenedByKeyBoardFlag: () => boolean;
    isMenuItemDataCollectedFlag: () => boolean;
    getSubMenuInstanceContext: () => SubMenuContext | null;
    getParentContext: () => SubMenuParentContext | null;
    getElement: () => HTMLElement | null;
}
declare const _default: import("vue").DefineComponent<{
    /**
     * Items from options
     */
    items: {
        type: PropType<MenuItem[]>;
        default: null;
    };
    /**
     * Max width for this submenu
     */
    maxWidth: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    /**
     * Min width for this submenu
     */
    minWidth: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    /**
     * Specifies should submenu adjust it position
     * when the menu exceeds the screen. The default is true
     */
    adjustPosition: {
        type: BooleanConstructor;
        default: boolean;
    };
}, {
    menu: import("vue").Ref<HTMLElement | undefined>;
    scroll: import("vue").Ref<HTMLElement | undefined>;
    options: MenuOptions;
    zIndex: number;
    constOptions: {
        defaultMinWidth: number;
        defaultMaxWidth: number;
        defaultZindex: number;
        defaultAdjustPadding: number;
    };
    scrollValue: import("vue").Ref<number>;
    overflow: import("vue").Ref<boolean>;
    position: import("vue").Ref<{
        x: number;
        y: number;
    }>;
    scrollHeight: import("vue").Ref<number>;
    maxHeight: import("vue").Ref<number>;
    globalHasSlot: GlobalHasSlot;
    globalRenderSlot: GlobalRenderSlot;
    globalTheme: string;
    onScroll: (down: boolean) => void;
    onSubMenuBodyClick: () => void;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * Items from options
     */
    items: {
        type: PropType<MenuItem[]>;
        default: null;
    };
    /**
     * Max width for this submenu
     */
    maxWidth: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    /**
     * Min width for this submenu
     */
    minWidth: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    /**
     * Specifies should submenu adjust it position
     * when the menu exceeds the screen. The default is true
     */
    adjustPosition: {
        type: BooleanConstructor;
        default: boolean;
    };
}>>, {
    maxWidth: string | number;
    minWidth: string | number;
    items: MenuItem[];
    adjustPosition: boolean;
}>;
/**
 * Submenu container
 */
export default _default;
